colour.plotting.notation Module — Colour 0.3.0 documentation

# colour.plotting.notation Module

## Colour Notation Systems Plotting

Defines the colour notation systems plotting objects:

- `single_munsell_value_function_plot()`
- `multi_munsell_value_function_plot()`

`colour.plotting.notation.` `single_munsell_value_function_plot`(function='ASTM D1535-08', **kwargs)

  Plots given Lightness function.

  Parameters: | function (unicode, optional) – Munsell value function to plot. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> f = 'ASTM D1535-08'
      >>> single_munsell_value_function_plot(f)
      True

`colour.plotting.notation.` `multi_munsell_value_function_plot`(*args, **kwargs)

  Plots given Munsell value functions.

  Parameters: | functions (array_like, optional) – Munsell value functions to plot. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool
  Raises: | `KeyError` – If one of the given Munsell value function is not found in the factory Munsell value functions.

  Examples

      >>> fs = ('ASTM D1535-08', 'McCamy 1987')
      >>> multi_munsell_value_function_plot(fs)
      True